@@ -3,7 +3,7 @@ from .bulk_update_cost_center_input_params import BulkUpdateCostCenterInputParam
 from travelperk_python_api_types.cost_centers.cost_centers.bulk_update_response import (
     BulkUpdateResponse,
 )
-from travelperk_http_python.dataclass_wrapper.dataclass_wrapper import DataclassWrapper
+from dataclass_map_and_log.mapper import DataclassMapper
 
 if TYPE_CHECKING:
     from api.travelperk import TravelPerk
@@ -15,7 +15,7 @@ class BulkUpdateCostCenterRequest:
         self.travelperk = travelperk
 
     def save(self) -> BulkUpdateResponse:
-        return DataclassWrapper.wrap(
+        return DataclassMapper.map(
             BulkUpdateResponse,
             self.travelperk.patch(
                 "/".join(["cost_centers", "bulk_update"]),
