@@ -3,7 +3,7 @@ from .set_users_for_cost_center_input_params import SetUsersForCostCenterInputPa
 from travelperk_python_api_types.cost_centers.cost_centers.cost_center_detail import (
     CostCenterDetail,
 )
-from travelperk_http_python.dataclass_wrapper.dataclass_wrapper import DataclassWrapper
+from dataclass_map_and_log.mapper import DataclassMapper
 
 if TYPE_CHECKING:
     from api.travelperk import TravelPerk
@@ -16,7 +16,7 @@ class SetUsersForCostCenterRequest:
         self.travelperk = travelperk
 
     def save(self) -> CostCenterDetail:
-        return DataclassWrapper.wrap(
+        return DataclassMapper.map(
             CostCenterDetail,
             self.travelperk.put(
                 "/".join(["cost_centers", self.id, "users"]), self.params.to_dict()
