@@ -3,7 +3,7 @@ from .update_cost_center_input_params import UpdateCostCenterInputParams
 from travelperk_python_api_types.cost_centers.cost_centers.cost_center_detail import (
     CostCenterDetail,
 )
-from travelperk_http_python.dataclass_wrapper.dataclass_wrapper import DataclassWrapper
+from dataclass_map_and_log.mapper import DataclassMapper
 
 if TYPE_CHECKING:
     from api.travelperk import TravelPerk
@@ -16,7 +16,7 @@ class UpdateCostCenterRequest:
         self.travelperk = travelperk
 
     def save(self) -> CostCenterDetail:
-        return DataclassWrapper.wrap(
+        return DataclassMapper.map(
             CostCenterDetail,
             self.travelperk.patch(
                 "/".join(["cost_centers", str(self.id)]), self.params.to_dict()
