@@ -4,7 +4,7 @@ from .invoices_input_params import InvoicesInputParams
 from travelperk_python_api_types.expenses.invoices.invoices import (
     Invoices as InvoicesType,
 )
-from travelperk_http_python.dataclass_wrapper.dataclass_wrapper import DataclassWrapper
+from dataclass_map_and_log.mapper import DataclassMapper
 
 if TYPE_CHECKING:
     from travelperk_http_python.api.travelperk import TravelPerk
@@ -20,7 +20,7 @@ class InvoicesQuery:
         return getattr(self.travelperk, method)(url)
 
     def get(self) -> InvoicesType:
-        return DataclassWrapper.wrap(
+        return DataclassMapper.map(
             InvoicesType,
             self.execute(
                 "get", "/".join(["invoices"]) + "?" + self.params.as_url_param()
