@@ -2,7 +2,7 @@ import urllib
 
 
 class CarEmissionsParams:
-    def __init__(self, acriss_code: str, num_days: int, distance_per_day: int):
+    def __init__(self, acriss_code: str, num_days: int, distance_per_day: int = None):
         self.set_acriss_code(acriss_code)
         self.set_num_days(num_days)
         self.set_distance_per_day(distance_per_day)
@@ -20,10 +20,11 @@ class CarEmissionsParams:
         return self
 
     def as_url_param(self) -> str:
-        return urllib.parse.urlencode(
-            {
-                "acriss_code": self.acriss_code,
-                "num_days": self.num_days,
-                "distance_per_day": self.distance_per_day,
-            }
-        )
+        data = {
+            "acriss_code": self.acriss_code,
+            "num_days": self.num_days,
+            "distance_per_day": self.distance_per_day
+            if self.distance_per_day is not None
+            else None,
+        }
+        return urllib.parse.urlencode({k: v for k, v in data.items() if v is not None})
