@@ -5,7 +5,7 @@ from travelperk_http_python.scim.name_input_params import NameInputParams
 from travelperk_http_python.scim.create_user_input_params import CreateUserInputParams
 from travelperk_python_api_types.scim.users.user import User
 from travelperk_http_python.scim.emergency_contact import EmergencyContact
-from travelperk_http_python.dataclass_wrapper.dataclass_wrapper import DataclassWrapper
+from dataclass_map_and_log.mapper import DataclassMapper
 
 if TYPE_CHECKING:
     from travelperk_http_python.api.travelperk import TravelPerk
@@ -50,7 +50,7 @@ class CreateUserQuery:
         return response
 
     def save(self) -> User:
-        return DataclassWrapper.wrap(
+        return DataclassMapper.map(
             User,
             humps.decamelize(
                 self.execute("post", "/".join(["scim", "Users"]), self.params.to_dict())
