@@ -1,7 +1,7 @@
 from typing import TYPE_CHECKING, List
 from .update_webhook_input_params import UpdateWebhookInputParams
 from travelperk_python_api_types.webhooks.webhooks.webhook import Webhook
-from travelperk_http_python.dataclass_wrapper.dataclass_wrapper import DataclassWrapper
+from dataclass_map_and_log.mapper import DataclassMapper
 
 if TYPE_CHECKING:
     from api.travelperk import TravelPerk
@@ -14,7 +14,7 @@ class UpdateWebhookRequest:
         self.travelperk = travelperk
 
     def save(self) -> Webhook:
-        return DataclassWrapper.wrap(
+        return DataclassMapper.map(
             Webhook,
             self.travelperk.patch(
                 "/".join(["webhooks", self.id]), self.params.to_dict()
